@@ -7,83 +7,52 @@ import (
 	"encoding/pem"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"regexp"
 	"sort"
 	"strings"
 	"sync"
 	"time"
 
-	configv1 "github.com/openshift/api/config/v1"
-	configv1client "github.com/openshift/client-go/config/clientset/versioned/typed/config/v1"
-
 	corev1 "k8s.io/api/core/v1"
-	policyv1beta1 "k8s.io/api/policy/v1beta1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
-	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/apimachinery/pkg/runtime/serializer"
 	"k8s.io/apimachinery/pkg/util/json"
 	utilruntime "k8s.io/apimachinery/pkg/util/runtime"
 	"k8s.io/apimachinery/pkg/util/sets"
-	"k8s.io/client-go/dynamic"
 	kubescheme "k8s.io/client-go/kubernetes/scheme"
 	certificatesv1beta1 "k8s.io/client-go/kubernetes/typed/certificates/v1beta1"
 	corev1client "k8s.io/client-go/kubernetes/typed/core/v1"
-	policyclient "k8s.io/client-go/kubernetes/typed/policy/v1beta1"
 	"k8s.io/client-go/rest"
 	"k8s.io/klog"
 
+	configv1 "github.com/openshift/api/config/v1"
 	registryv1 "github.com/openshift/api/imageregistry/v1"
-	networkv1 "github.com/openshift/api/network/v1"
 	openshiftscheme "github.com/openshift/client-go/config/clientset/versioned/scheme"
+	configv1client "github.com/openshift/client-go/config/clientset/versioned/typed/config/v1"
 	imageregistryv1 "github.com/openshift/client-go/imageregistry/clientset/versioned/typed/imageregistry/v1"
-	networkv1client "github.com/openshift/client-go/network/clientset/versioned/typed/network/v1"
 
 	"github.com/openshift/insights-operator/pkg/record"
-	"github.com/openshift/insights-operator/pkg/record/diskrecorder"
-)
-
-const (
-	// metricsAlertsLinesLimit is the maximal number of lines read from monitoring Prometheus
-	// 500 KiB of alerts is limit, one alert line has typically 450 bytes => 1137 lines.
-	// This number has been rounded to 1000 for simplicity.
-	// Formerly, the `500 * 1024 / 450` expression was used instead.
-	metricsAlertsLinesLimit        = 1000
-	gatherPodDisruptionBudgetLimit = 5000
-
-	// Log compression ratio is defining a multiplier for uncompressed logs
-	// diskrecorder would refuse to write files larger than MaxLogSize, so GatherClusterOperators
-	// has to limit the expected size of the buffer for logs
-	logCompressionRatio = 2
 )
 
 var (
-	openshiftSerializer     = openshiftscheme.Codecs.LegacyCodec(configv1.SchemeGroupVersion)
-	kubeSerializer          = kubescheme.Codecs.LegacyCodec(corev1.SchemeGroupVersion)
-	policyV1Beta1Serializer = kubescheme.Codecs.LegacyCodec(policyv1beta1.SchemeGroupVersion)
+	openshiftSerializer = openshiftscheme.Codecs.LegacyCodec(configv1.SchemeGroupVersion)
+	kubeSerializer      = kubescheme.Codecs.LegacyCodec(corev1.SchemeGroupVersion)
 
 	// maxEventTimeInterval represents the "only keep events that are maximum 1h old"
 	// TODO: make this dynamic like the reporting window based on configured interval
 	maxEventTimeInterval = 1 * time.Hour
 
+	registrySerializer serializer.CodecFactory
+	registryScheme     = runtime.NewScheme()
+
 	// logTailLines defines a number lines to keep when fetching pod logs
 	logTailLines = int64(100)
-
-	registrySerializer serializer.CodecFactory
-	networkSerializer  serializer.CodecFactory
-	registryScheme     = runtime.NewScheme()
-	networkScheme      = runtime.NewScheme()
-
-	// lineSep is the line separator used by the alerts metric
-	lineSep = []byte{'\n'}
 )
 
 func init() {
 	utilruntime.Must(registryv1.AddToScheme(registryScheme))
-	utilruntime.Must(networkv1.AddToScheme(networkScheme))
-	networkSerializer = serializer.NewCodecFactory(networkScheme)
 	registrySerializer = serializer.NewCodecFactory(registryScheme)
 }
 
@@ -91,28 +60,22 @@ func init() {
 type Gatherer struct {
 	client         configv1client.ConfigV1Interface
 	coreClient     corev1client.CoreV1Interface
-	dynamicClient  dynamic.Interface
-	networkClient  networkv1client.NetworkV1Interface
 	metricsClient  rest.Interface
 	certClient     certificatesv1beta1.CertificatesV1beta1Interface
 	registryClient imageregistryv1.ImageregistryV1Interface
-	policyClient   policyclient.PolicyV1beta1Interface
 	lock           sync.Mutex
 	lastVersion    *configv1.ClusterVersion
 }
 
 // New creates new Gatherer
 func New(client configv1client.ConfigV1Interface, coreClient corev1client.CoreV1Interface, certClient certificatesv1beta1.CertificatesV1beta1Interface, metricsClient rest.Interface,
-	registryClient imageregistryv1.ImageregistryV1Interface, networkClient networkv1client.NetworkV1Interface, dynamicClient dynamic.Interface, policyClient policyclient.PolicyV1beta1Interface) *Gatherer {
+	registryClient imageregistryv1.ImageregistryV1Interface) *Gatherer {
 	return &Gatherer{
 		client:         client,
 		coreClient:     coreClient,
 		certClient:     certClient,
 		metricsClient:  metricsClient,
 		registryClient: registryClient,
-		networkClient:  networkClient,
-		dynamicClient:  dynamicClient,
-		policyClient:   policyClient,
 	}
 }
 
@@ -121,10 +84,9 @@ var reInvalidUIDCharacter = regexp.MustCompile(`[^a-z0-9\-]`)
 // Gather is hosting and calling all the recording functions
 func (i *Gatherer) Gather(ctx context.Context, recorder record.Interface) error {
 	return record.Collect(ctx, recorder,
-		GatherPodDisruptionBudgets(i),
 		GatherMostRecentMetrics(i),
 		GatherClusterOperators(i),
-		GatherNodes(i),
+		GatherUnhealthyNodes(i),
 		GatherConfigMaps(i),
 		GatherClusterVersion(i),
 		GatherClusterID(i),
@@ -132,48 +94,22 @@ func (i *Gatherer) Gather(ctx context.Context, recorder record.Interface) error
 		GatherClusterNetwork(i),
 		GatherClusterAuthentication(i),
 		GatherClusterImageRegistry(i),
+		GatherClusterImagePruner(i),
 		GatherClusterFeatureGates(i),
 		GatherClusterOAuth(i),
 		GatherClusterIngress(i),
 		GatherClusterProxy(i),
 		GatherCertificateSigningRequests(i),
-		GatherHostSubnet(i),
-		GatherMachineSet(i),
 	)
 }
 
-// GatherPodDisruptionBudgets gathers the cluster's PodDisruptionBudgets.
-//
-// The Kubernetes api https://github.com/kubernetes/client-go/blob/v11.0.0/kubernetes/typed/policy/v1beta1/poddisruptionbudget.go#L80
-// Response see https://docs.okd.io/latest/rest_api/policy_apis/poddisruptionbudget-policy-v1beta1.html
-//
-// Location in archive: config/pdbs/
-// See: docs/insights-archive-sample/config/pdbs
-func GatherPodDisruptionBudgets(i *Gatherer) func() ([]record.Record, []error) {
-	return func() ([]record.Record, []error) {
-		pdbs, err := i.policyClient.PodDisruptionBudgets("").List(metav1.ListOptions{Limit: gatherPodDisruptionBudgetLimit})
-		if err != nil {
-			return nil, []error{err}
-		}
-		records := []record.Record{}
-		for _, pdb := range pdbs.Items {
-			records = append(records, record.Record{
-				Name: fmt.Sprintf("config/pdbs/%s", pdb.GetName()),
-				Item: PodDisruptionBudgetsAnonymizer{&pdb},
-			})
-		}
-		return records, nil
-	}
-}
-
 // GatherMostRecentMetrics gathers cluster Federated Monitoring metrics.
 //
 // The GET REST query to URL /federate
 // Gathered metrics:
+//   ALERTS
 //   etcd_object_counts
 //   cluster_installer
-//   namespace CPU and memory usage
-//   followed by at most 1000 lines of ALERTS metric
 //
 // Location in archive: config/metrics/
 // See: docs/insights-archive-sample/config/metrics
@@ -183,6 +119,7 @@ func GatherMostRecentMetrics(i *Gatherer) func() ([]record.Record, []error) {
 			return nil, nil
 		}
 		data, err := i.metricsClient.Get().AbsPath("federate").
+			Param("match[]", "ALERTS").
 			Param("match[]", "etcd_object_counts").
 			Param("match[]", "cluster_installer").
 			DoRaw()
@@ -191,34 +128,6 @@ func GatherMostRecentMetrics(i *Gatherer) func() ([]record.Record, []error) {
 			klog.Errorf("Unable to retrieve most recent metrics: %v", err)
 			return []record.Record{{Name: "config/metrics", Item: RawByte(fmt.Sprintf("# error: %v\n", err))}}, nil
 		}
-
-		rsp, err := i.metricsClient.Get().AbsPath("federate").
-			Param("match[]", "ALERTS").
-			Stream()
-		if err != nil {
-			// write metrics errors to the file format as a comment
-			klog.Errorf("Unable to retrieve most recent alerts from metrics: %v", err)
-			return []record.Record{{Name: "config/metrics", Item: RawByte(fmt.Sprintf("# error: %v\n", err))}}, nil
-		}
-		r := NewLineLimitReader(rsp, metricsAlertsLinesLimit)
-		alerts, err := ioutil.ReadAll(r)
-		if err != nil && err != io.EOF {
-			klog.Errorf("Unable to read most recent alerts from metrics: %v", err)
-			return nil, []error{err}
-		}
-
-		remainingAlertLines, err := countLines(rsp)
-		if err != nil && err != io.EOF {
-			klog.Errorf("Unable to count truncated lines of alerts metric: %v", err)
-			return nil, []error{err}
-		}
-		totalAlertCount := r.GetTotalLinesRead() + remainingAlertLines
-
-		// # ALERTS <Total Alerts Lines>/<Alerts Line Limit>
-		// The total number of alerts will typically be greater than the true number of alerts by 2
-		// because the `# TYPE ALERTS untyped` header and the final empty line are counter in.
-		data = append(data, []byte(fmt.Sprintf("# ALERTS %d/%d\n", totalAlertCount, metricsAlertsLinesLimit))...)
-		data = append(data, alerts...)
 		records := []record.Record{
 			{Name: "config/metrics", Item: RawByte(data)},
 		}
@@ -251,7 +160,6 @@ func GatherClusterOperators(i *Gatherer) func() ([]record.Record, []error) {
 		}
 		namespaceEventsCollected := sets.NewString()
 		now := time.Now()
-		unhealthyPods := []*corev1.Pod{}
 		for _, item := range config.Items {
 			if isHealthyOperator(&item) {
 				continue
@@ -268,7 +176,34 @@ func GatherClusterOperators(i *Gatherer) func() ([]record.Record, []error) {
 						continue
 					}
 					records = append(records, record.Record{Name: fmt.Sprintf("config/pod/%s/%s", pod.Namespace, pod.Name), Item: PodAnonymizer{pod}})
-					unhealthyPods = append(unhealthyPods, pod)
+
+					// Fetch previous and current pod logs
+					for _, previous := range []bool{true, false} {
+						for _, container := range pod.Spec.Containers {
+							currentOrPrevious := fmt.Sprintf("%s_current.log", container.Name)
+							if previous {
+								currentOrPrevious = fmt.Sprintf("%s_previous.log", container.Name)
+							}
+
+							req := i.coreClient.Pods(namespace).GetLogs(pod.Name, &corev1.PodLogOptions{Previous: previous, TailLines: &logTailLines, Container: container.Name})
+							readCloser, err := req.Stream()
+							if err != nil {
+								klog.V(2).Infof("Failed to fetch %s for %s pod in namespace %s for failing operator %s: %q", currentOrPrevious, pod.Name, namespace, item.Name, err)
+								continue
+							}
+
+							defer readCloser.Close()
+
+							buf := bytes.NewBufferString("")
+							_, err = io.Copy(buf, readCloser)
+							if err != nil {
+								klog.V(2).Infof("Failed to write %s for %s pod in namespace %s for failing operator %s: %q", currentOrPrevious, pod.Name, namespace, item.Name, err)
+								continue
+							}
+
+							records = append(records, record.Record{Name: fmt.Sprintf("config/pod/%s/logs/%s/%s", pod.Namespace, pod.Name, currentOrPrevious), Item: Raw{buf.String()}})
+						}
+					}
 				}
 				if namespaceEventsCollected.Has(namespace) {
 					continue
@@ -282,76 +217,22 @@ func GatherClusterOperators(i *Gatherer) func() ([]record.Record, []error) {
 				namespaceEventsCollected.Insert(namespace)
 			}
 		}
-
-		// Exit early if no unhealthy pods found
-		if len(unhealthyPods) == 0 {
-			return records, nil
-		}
-
-		// Fetch a list of containers in unhealthy pods and calculate a log size quota
-		// Total log size must not exceed maxLogsSize multiplied by logCompressionRatio
-		klog.V(2).Infof("Found %d unhealthy pods", len(unhealthyPods))
-		totalUnhealthyContainers := 0
-		for _, pod := range unhealthyPods {
-			totalUnhealthyContainers += len(pod.Spec.InitContainers) + len(pod.Spec.Containers)
-		}
-		bufferSize := int64(diskrecorder.MaxLogSize * logCompressionRatio / totalUnhealthyContainers / 2)
-		klog.V(2).Infof("Maximum buffer size: %v bytes", bufferSize)
-		buf := bytes.NewBuffer(make([]byte, 0, bufferSize))
-
-		// Fetch previous and current container logs
-		for _, isPrevious := range []bool{true, false} {
-			for _, pod := range unhealthyPods {
-				allContainers := pod.Spec.InitContainers
-				allContainers = append(allContainers, pod.Spec.Containers...)
-				for _, c := range allContainers {
-					logName := fmt.Sprintf("%s_current.log", c.Name)
-					if isPrevious {
-						logName = fmt.Sprintf("%s_previous.log", c.Name)
-					}
-					buf.Reset()
-					klog.V(2).Infof("Fetching logs for %s container %s pod in namespace %s (previous: %v): %q", c.Name, pod.Name, pod.Namespace, isPrevious, err)
-					// Collect container logs and continue on error
-					err = collectContainerLogs(i, pod, buf, c.Name, isPrevious, &bufferSize)
-					if err != nil {
-						klog.V(2).Infof("Error: %q", err)
-						continue
-					}
-					records = append(records, record.Record{Name: fmt.Sprintf("config/pod/%s/logs/%s/%s", pod.Namespace, pod.Name, logName), Item: Raw{buf.String()}})
-				}
-			}
-		}
-
 		return records, nil
 	}
 }
 
-// collectContainerLogs fetches log lines from the pod
-func collectContainerLogs(i *Gatherer, pod *corev1.Pod, buf *bytes.Buffer, containerName string, isPrevious bool, maxBytes *int64) error {
-	req := i.coreClient.Pods(pod.Namespace).GetLogs(pod.Name, &corev1.PodLogOptions{Previous: isPrevious, Container: containerName, LimitBytes: maxBytes, TailLines: &logTailLines})
-	readCloser, err := req.Stream()
-	if err != nil {
-		klog.V(2).Infof("Failed to fetch log for %s pod in namespace %s for failing operator %s (previous: %v): %q", pod.Name, pod.Namespace, containerName, isPrevious, err)
-		return err
-	}
-
-	defer readCloser.Close()
-
-	_, err = io.Copy(buf, readCloser)
-	if err != nil && err != io.ErrShortBuffer {
-		klog.V(2).Infof("Failed to write log for %s pod in namespace %s for failing operator %s (previous: %v): %q", pod.Name, pod.Namespace, containerName, isPrevious, err)
-		return err
-	}
-	return nil
-}
-
-// GatherNodes collects all Nodes.
+// GatherUnhealthyNodes collects all unhealthy Nodes.
+//
+// The node is unhealthy when:
+// the operator.Status.Conditions.Condition Type
+//   is OperatorDegrated and Status is True or
+//      OperatorAvailable and Status is False
 //
 // The Kubernetes api https://github.com/kubernetes/client-go/blob/master/kubernetes/typed/core/v1/node.go#L78
 // Response see https://docs.openshift.com/container-platform/4.3/rest_api/index.html#nodelist-v1core
 //
 // Location in archive: config/node/
-func GatherNodes(i *Gatherer) func() ([]record.Record, []error) {
+func GatherUnhealthyNodes(i *Gatherer) func() ([]record.Record, []error) {
 	return func() ([]record.Record, []error) {
 		nodes, err := i.coreClient.Nodes().List(metav1.ListOptions{})
 		if err != nil {
@@ -359,6 +240,9 @@ func GatherNodes(i *Gatherer) func() ([]record.Record, []error) {
 		}
 		records := make([]record.Record, 0, len(nodes.Items))
 		for i := range nodes.Items {
+			if isHealthyNode(&nodes.Items[i]) {
+				continue
+			}
 			records = append(records, record.Record{Name: fmt.Sprintf("config/node/%s", nodes.Items[i].Name), Item: NodeAnonymizer{&nodes.Items[i]}})
 		}
 
@@ -475,29 +359,6 @@ func GatherClusterNetwork(i *Gatherer) func() ([]record.Record, []error) {
 	}
 }
 
-// GatherHostSubnet collects HostSubnet information
-//
-// The Kubernetes api https://github.com/openshift/client-go/blob/master/network/clientset/versioned/typed/network/v1/hostsubnet.go
-// Response see https://docs.openshift.com/container-platform/4.3/rest_api/index.html#hostsubnet-v1-network-openshift-io
-//
-// Location in archive: config/hostsubnet/
-func GatherHostSubnet(i *Gatherer) func() ([]record.Record, []error) {
-	return func() ([]record.Record, []error) {
-		hostSubnetList, err := i.networkClient.HostSubnets().List(metav1.ListOptions{})
-		if errors.IsNotFound(err) {
-			return nil, nil
-		}
-		if err != nil {
-			return nil, []error{err}
-		}
-		records := make([]record.Record, 0, len(hostSubnetList.Items))
-		for _, h := range hostSubnetList.Items {
-			records = append(records, record.Record{Name: fmt.Sprintf("config/hostsubnet/%s", h.Host), Item: HostSubnetAnonymizer{&h}})
-		}
-		return records, nil
-	}
-}
-
 // GatherClusterAuthentication fetches the cluster Authentication - the Authentication with name cluster.
 //
 // The Kubernetes api https://github.com/openshift/client-go/blob/master/config/clientset/versioned/typed/config/v1/authentication.go#L50
@@ -518,6 +379,22 @@ func GatherClusterAuthentication(i *Gatherer) func() ([]record.Record, []error)
 	}
 }
 
+// GatherClusterImagePruner fetches the image pruner configuration
+//
+// Location in archive: config/imagepruner/
+func GatherClusterImagePruner(i *Gatherer) func() ([]record.Record, []error) {
+	return func() ([]record.Record, []error) {
+		pruner, err := i.registryClient.ImagePruners().Get("cluster", metav1.GetOptions{})
+		if errors.IsNotFound(err) {
+			return nil, nil
+		}
+		if err != nil {
+			return nil, []error{err}
+		}
+		return []record.Record{{Name: "config/imagepruner", Item: ImagePrunerAnonymizer{pruner}}}, nil
+	}
+}
+
 // GatherClusterImageRegistry fetches the cluster Image Registry configuration
 //
 // Location in archive: config/imageregistry/
@@ -642,33 +519,6 @@ func GatherCertificateSigningRequests(i *Gatherer) func() ([]record.Record, []er
 	}
 }
 
-//GatherMachineSet collects MachineSet information
-//
-// The Kubernetes api https://github.com/openshift/machine-api-operator/blob/master/pkg/generated/clientset/versioned/typed/machine/v1beta1/machineset.go
-// Response see https://docs.openshift.com/container-platform/4.3/rest_api/index.html#machineset-v1beta1-machine-openshift-io
-//
-// Location in archive: machinesets/
-func GatherMachineSet(i *Gatherer) func() ([]record.Record, []error) {
-	return func() ([]record.Record, []error) {
-		gvr := schema.GroupVersionResource{Group: "machine.openshift.io", Version: "v1beta1", Resource: "machinesets"}
-		machineSets, err := i.dynamicClient.Resource(gvr).List(metav1.ListOptions{})
-		if errors.IsNotFound(err) {
-			return nil, nil
-		}
-		if err != nil {
-			return nil, []error{err}
-		}
-		records := []record.Record{}
-		for _, i := range machineSets.Items {
-			records = append(records, record.Record{
-				Name: fmt.Sprintf("machinesets/%s", i.GetName()),
-				Item: record.JSONMarshaller{Object: i.Object},
-			})
-		}
-		return records, nil
-	}
-}
-
 func (i *Gatherer) gatherNamespaceEvents(namespace string) ([]record.Record, []error) {
 	// do not accidentally collect events for non-openshift namespace
 	if !strings.HasPrefix(namespace, "openshift-") {
@@ -785,11 +635,26 @@ func (a FeatureGateAnonymizer) Marshal(_ context.Context) ([]byte, error) {
 	return runtime.Encode(openshiftSerializer, a.FeatureGate)
 }
 
-// GetExtension returns extension for anonymized cluster version objects
+// GetExtension returns extension for anonymized feature gate objects
 func (a FeatureGateAnonymizer) GetExtension() string {
 	return "json"
 }
 
+// ImagePrunerAnonymizer implements serialization with marshalling
+type ImagePrunerAnonymizer struct {
+	*registryv1.ImagePruner
+}
+
+// Marshal serializes ImagePruner with anonymization
+func (a ImagePrunerAnonymizer) Marshal(_ context.Context) ([]byte, error) {
+	return runtime.Encode(registrySerializer.LegacyCodec(registryv1.SchemeGroupVersion), a.ImagePruner)
+}
+
+// GetExtension returns extension for anonymized image pruner objects
+func (a ImagePrunerAnonymizer) GetExtension() string {
+	return "json"
+}
+
 // ImageRegistryAnonymizer implements serialization with marshalling
 type ImageRegistryAnonymizer struct {
 	*registryv1.Config
@@ -825,7 +690,7 @@ func (a ImageRegistryAnonymizer) Marshal(_ context.Context) ([]byte, error) {
 	return runtime.Encode(registrySerializer.LegacyCodec(registryv1.SchemeGroupVersion), a.Config)
 }
 
-// GetExtension returns extension for anonymized feature gate objects
+// GetExtension returns extension for anonymized image registry objects
 func (a ImageRegistryAnonymizer) GetExtension() string {
 	return "json"
 }
@@ -982,18 +847,19 @@ func anonymizeString(s string) string {
 	return strings.Repeat("x", len(s))
 }
 
-func anonymizeSliceOfStrings(slice []string) []string {
-	anonymizedSlice := make([]string, len(slice), len(slice))
-	for i, s := range slice {
-		anonymizedSlice[i] = anonymizeString(s)
-	}
-	return anonymizedSlice
-}
-
 func isProductNamespacedKey(key string) bool {
 	return strings.Contains(key, "openshift.io/") || strings.Contains(key, "k8s.io/") || strings.Contains(key, "kubernetes.io/")
 }
 
+func isHealthyNode(node *corev1.Node) bool {
+	for _, condition := range node.Status.Conditions {
+		if condition.Type == corev1.NodeReady && condition.Status != corev1.ConditionTrue {
+			return false
+		}
+	}
+	return true
+}
+
 // PodAnonymizer implements serialization with anonymization for a Pod
 type PodAnonymizer struct{ *corev1.Pod }
 
@@ -1013,20 +879,6 @@ func anonymizePod(pod *corev1.Pod) *corev1.Pod {
 	return pod
 }
 
-type PodDisruptionBudgetsAnonymizer struct {
-	*policyv1beta1.PodDisruptionBudget
-}
-
-// Marshal implements serialization of a PodDisruptionBudget with anonymization
-func (a PodDisruptionBudgetsAnonymizer) Marshal(_ context.Context) ([]byte, error) {
-	return runtime.Encode(policyV1Beta1Serializer, a.PodDisruptionBudget)
-}
-
-// GetExtension returns extension for anonymized PodDisruptionBudget objects
-func (a PodDisruptionBudgetsAnonymizer) GetExtension() string {
-	return "json"
-}
-
 func isHealthyPod(pod *corev1.Pod, now time.Time) bool {
 	// pending pods may be unable to schedule or start due to failures, and the info they provide in status is important
 	// for identifying why scheduling has not happened
@@ -1095,28 +947,11 @@ func (a ConfigMapAnonymizer) Marshal(_ context.Context) ([]byte, error) {
 	return c, nil
 }
 
-// GetExtension returns extension for anonymized configmap objects
+// GetExtension returns extension for anonymized openshift objects
 func (a ConfigMapAnonymizer) GetExtension() string {
 	return ""
 }
 
-// HostSubnetAnonymizer implements HostSubnet serialization wiht anonymization
-type HostSubnetAnonymizer struct{ *networkv1.HostSubnet }
-
-// Marshal implements HostSubnet serialization
-func (a HostSubnetAnonymizer) Marshal(_ context.Context) ([]byte, error) {
-	a.HostSubnet.HostIP = anonymizeString(a.HostSubnet.HostIP)
-	a.HostSubnet.Subnet = anonymizeString(a.HostSubnet.Subnet)
-	a.HostSubnet.EgressIPs = anonymizeSliceOfStrings(a.HostSubnet.EgressIPs)
-	a.HostSubnet.EgressCIDRs = anonymizeSliceOfStrings(a.HostSubnet.EgressCIDRs)
-	return runtime.Encode(networkSerializer.LegacyCodec(networkv1.SchemeGroupVersion), a.HostSubnet)
-}
-
-// GetExtension returns extension for HostSubnet object
-func (a HostSubnetAnonymizer) GetExtension() string {
-	return "json"
-}
-
 func anonymizeConfigMap(dv []byte) string {
 	anonymizedPemBlock := `-----BEGIN CERTIFICATE-----
 ANONYMIZED
@@ -1138,60 +973,3 @@ ANONYMIZED
 	}
 	return sb.String()
 }
-
-// NewLineLimitReader returns a Reader that reads from `r` but stops with EOF after `n` lines.
-func NewLineLimitReader(r io.Reader, n int) *LineLimitedReader { return &LineLimitedReader{r, n, 0} }
-
-// A LineLimitedReader reads from R but limits the amount of
-// data returned to just N lines. Each call to Read
-// updates N to reflect the new amount remaining.
-// Read returns EOF when N <= 0 or when the underlying R returns EOF.
-type LineLimitedReader struct {
-	reader        io.Reader // underlying reader
-	maxLinesLimit int       // max lines remaining
-	// totalLinesRead is the total number of line separators already read by the underlying reader.
-	totalLinesRead int
-}
-
-func (l *LineLimitedReader) Read(p []byte) (int, error) {
-	if l.maxLinesLimit <= 0 {
-		return 0, io.EOF
-	}
-
-	rc, err := l.reader.Read(p)
-	l.totalLinesRead += bytes.Count(p[:rc], lineSep)
-
-	lc := 0
-	for {
-		lineSepIdx := bytes.Index(p[lc:rc], lineSep)
-		if lineSepIdx == -1 {
-			return rc, err
-		}
-		if l.maxLinesLimit <= 0 {
-			return lc, io.EOF
-		}
-		l.maxLinesLimit--
-		lc += lineSepIdx + 1 // skip past the EOF
-	}
-}
-
-// GetTotalLinesRead return the total number of line separators already read by the underlying reader.
-// This includes lines that have been truncated by the `Read` calls after exceeding the line limit.
-func (l *LineLimitedReader) GetTotalLinesRead() int { return l.totalLinesRead }
-
-// countLines reads the remainder of the reader and counts the number of lines.
-//
-// Inspired by: https://stackoverflow.com/a/24563853/
-func countLines(r io.Reader) (int, error) {
-	buf := make([]byte, 0x8000)
-	// Original implementation started from 0, but a file with no line separator
-	// still contains a single line, so I would say that was an off-by-1 error.
-	lineCount := 1
-	for {
-		c, err := r.Read(buf)
-		lineCount += bytes.Count(buf[:c], lineSep)
-		if err != nil {
-			return lineCount, err
-		}
-	}
-}
